==> pw-iso20022-SRU2020-9.1.3-sources.jar: com/prowidesoftware/swift/model/mx/dic/CorporateActionChangeType1Code.java <==

package com.prowidesoftware.swift.model.mx.dic;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CorporateActionChangeType1Code.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="CorporateActionChangeType1Code"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *     &lt;enumeration value="BERE"/&gt;
 *     &lt;enumeration value="CERT"/&gt;
 *     &lt;enumeration value="DEPH"/&gt;
 *     &lt;enumeration value="GPPH"/&gt;
 *     &lt;enumeration value="GTGP"/&gt;
 *     &lt;enumeration value="GTPH"/&gt;
 *     &lt;enumeration value="NAME"/&gt;
 *     &lt;enumeration value="PHDE"/&gt;
 *     &lt;enumeration value="REBE"/&gt;
 *     &lt;enumeration value="TERM"/&gt;
 *     &lt;enumeration value="DECI"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "CorporateActionChangeType1Code")
@XmlEnum
public enum CorporateActionChangeType1Code {


    /**
     * Change from bearer into registered form.
     * 
     */
    BERE,

    /**
     * Change of all instruments into certificates.
     * 
     */
    CERT,

    /**
     * Change from dematerialised into physical form.
     * 
     */
    DEPH,

    /**
     * Change from global permanent to physical form.
     * 
     */
    GPPH,

    /**
     * Change from global temporary to global permanent form.
     * 
     */
    GTGP,

    /**
     * Change from global temporary to physical form.
     * 
     */
    GTPH,

    /**
     * The issuing company changes its name. CA event shows the change from old name to new name and may involve surrendering physical shares with the old name to the registrar.
     * 
     */
    NAME,

    /**
     * Change from physical into dematerialised form.
     * 
     */
    PHDE,

    /**
     * Change from registered into bearer form.
     * 
     */
    REBE,

    /**
     * Change in the terms of the security.
     * 
     */
    TERM,

    /**
     * Process of changing the accounting method of a security, eg, mutual fund, from units to a quantity with decimals.
     * 
     */
    DECI;

    public String value() {
        return name();
    }

    public static CorporateActionChangeType1Code fromValue(String v) {
        return valueOf(v);
    }

}

==> pw-iso20022-SRU2022-9.3.4-sources.jar: com/prowidesoftware/swift/model/mx/dic/CorporateActionChangeType1Code.java <==

package com.prowidesoftware.swift.model.mx.dic;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CorporateActionChangeType1Code.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="CorporateActionChangeType1Code"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *     &lt;enumeration value="BERE"/&gt;
 *     &lt;enumeration value="CERT"/&gt;
 *     &lt;enumeration value="DEPH"/&gt;
 *     &lt;enumeration value="GPPH"/&gt;
 *     &lt;enumeration value="GTGP"/&gt;
 *     &lt;enumeration value="GTPH"/&gt;
 *     &lt;enumeration value="NAME"/&gt;
 *     &lt;enumeration value="PHDE"/&gt;
 *     &lt;enumeration value="REBE"/&gt;
 *     &lt;enumeration value="TERM"/&gt;
 *     &lt;enumeration value="DECI"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "CorporateActionChangeType1Code")
@XmlEnum
public enum CorporateActionChangeType1Code {


    /**
     * Change from bearer into registered form.
     * 
     */
    BERE,

    /**
     * Change of all instruments into certificates.
     * 
     */
    CERT,

    /**
     * Change from dematerialised into physical form.
     * 
     */
    DEPH,

    /**
     * Change from global permanent to physical form.
     * 
     */
    GPPH,

    /**
     * Change from global temporary to global permanent form.
     * 
     */
    GTGP,

    /**
     * Change from global temporary to physical form.
     * 
     */
    GTPH,

    /**
     * The issuing company changes its name. CA event shows the change from old name to new name and may involve surrendering physical shares with the old name to the registrar.
     * 
     */
    NAME,

    /**
     * Change from physical into dematerialised form.
     * 
     */
    PHDE,

    /**
     * Change from registered into bearer form.
     * 
     */
    REBE,

    /**
     * Change in the terms of the security.
     * 
     */
    TERM,

    /**
     * Process of changing the accounting method of a security, for example, mutual fund, from units to a quantity with decimals.
     * 
     */
    DECI;

    public String value() {
        return name();
    }

    public static CorporateActionChangeType1Code fromValue(String v) {
        return valueOf(v);
    }

}
